@@ -8,7 +8,7 @@ __docformat__ = "restructuredtext en"
 
 from datetime import date
 
-from logilab.common.date import date_range
+from logilab.common.date import ONEDAY, date_range
 
 from cubicweb.mixins import TreeMixIn
 from cubicweb.entities import AnyEntity, fetch_config
@@ -46,5 +46,6 @@ class Task(TreeMixIn, AnyEntity):
                 start = stop - cost/4
             else:
                 start = stop
-        return list(date_range(start, stop))
+        # date_range exclude the outer bound, hence + ONEDAY
+        return list(date_range(start, stop + ONEDAY))
 
